﻿#!/bin/bash

class1=com.ibm.ovf.kvm.system
class2=com.ibm.ovf.kvm.networking
echo "ProductClass1=$class1"
echo "ProductClass2=$class2"
echo "${class1}.product=General OS settings"
echo "${class2}.product=Networking settings"

distro=`gawk '/SUSE|Red Hat/' /etc/issue`
distro=${distro#Welcome to }

echo "$class1.1=distro"
echo "distro.value=${distro%%(*)*}"
echo "distro.type=string"
echo "distro.userConfigurable=false"
echo "distro.label=Linux distribution"
echo "distro.description=Distro name and level"

echo "$class1.2=kernel"
echo "kernel.value="`uname -rvi`
echo "kernel.type=string"
echo "kernel.userConfigurable=false"
echo "kernel.label=Linux kernel level"
echo "kernel.description=Kernel version, level, and HW platform"

nodename=`uname -n`
echo "$class1.3=hostname"
echo "hostname.value="
echo "hostname.type=string"
echo "hostname.userConfigurable=true"
echo "hostname.label=Short hostname of system"
echo "hostname.description=OS system shortname."

echo "$class1.4=configure.postaction"
echo "configure.postaction.value=none"
echo "configure.postaction.type=string"
echo "configure.postactionuserConfigurable=false"
echo "configure.postaction.label=Post-configure action"
echo "configure.postaction.description=The action to perform after the activation engine configures the software stack (shutdown, none)"

domain=`hostname -d`
if [ "$domain" = "" ]
then
  domain=`grep "search " /etc/resolv.conf | head -n 1 | gawk '{print $2}'`
fi

echo "$class1.4=domainname"
echo "domainname.value=$domain"
echo "domainname.type=string"
echo "domainname.userConfigurable=true"
echo "domainname.label=DNS domain name of system"
echo "domainname.description=Domain name."

echo "$class1.5=timezone.offest"
echo "timezone.offest.value="`date +%z`
echo "timezone.offest.type=uint16"
echo "timezone.offest.userConfigurable=true"
echo "timezone.offest.label=Time zone offset setting of virtual system"
echo "timezone.offest.description=Time zone offset setting of virtual system."

let num=0

let num=num+1
echo "$class2.$num=dns1.ip"
echo "dns1.ip.value="`grep "^nameserver" /etc/resolv.conf | gawk '{print "dns"NR, $2}' | gawk '/dns1/ {print $2}' | head -n 1`
echo "dns1.ip.type=string"
echo "dns1.ip.userConfigurable=true"
echo "dns1.ip.label=IP of first DNS server if applicable"
echo "dns1.ip.description=First DNS server IP."
echo "dns1.ip.category=General external networking"

let num=num+1
echo "$class2.$num=dns2.ip"
echo "dns2.ip.value="`grep "^nameserver" /etc/resolv.conf | gawk '{print "dns"NR, $2}' | gawk '/dns2/ {print $2}' | head -n 1`
echo "dns2.ip.type=string"
echo "dns2.ip.userConfigurable=true"
echo "dns2.ip.label=IP of second DNS server if applicable"
echo "dns2.ip.description=Second DNS server IP"


for ifc in $(netstat -i | gawk '/RU/ {print $1}'); do
  if [ "$ifc" != "lo" ]
  then
    usedhcp=true
    if [ -e /etc/sysconfig/network/ifcfg-$ifc ]
	then
	  file=/etc/sysconfig/network/ifcfg-$ifc
	else
	  file=/etc/sysconfig/network-scripts/ifcfg-$ifc
	fi
	#echo $file
	static=`gawk -F= '/static/ {print $2}' $file`
	#echo $static
	if [ "$static" = "" ]
	then
	  ipaddr=dhcp
	else
	  usedhcp=false
# Can grab other networking info from config file instead of what's running, tbd
	  ipaddr=$(ifconfig $ifc | sed -n 's/\s*inet addr:\(\S*\)\s.*/\1/p')
	fi
  
	let num=num+1
	echo "$class2.$num=networkport.$ifc.usedhcp"
	echo "networkport.$ifc.usedhcp.value=$usedhcp"
	echo "networkport.$ifc.usedhcp.type=boolean"
	echo "networkport.$ifc.usedhcp.userConfigurable=true"
	echo "networkport.$ifc.usedhcp.label=Use DHCP for $ifc"
	echo "networkport.$ifc.usedhcp.description=Specifies whether DHCP is used for the network interface."
	echo "networkport.$ifc.usedhcp.category=Network interface settings for $ifc"

	let num=num+1
	echo "$class2.$num=networkport.$ifc.ip"
	echo "networkport.$ifc.ip.value="
	echo "networkport.$ifc.ip.type=string"
	echo "networkport.$ifc.ip.userConfigurable=true"
	echo "networkport.$ifc.ip.label=IP address for $ifc"
	echo "networkport.$ifc.ip.description=IP Address for the network interface, if not using DHCP (IP V4 or V6 format)."

	let num=num+1
	gateway=$(route | grep $ifc | gawk '/default/ {print $2}')
	echo "$class2.$num=networkport.$ifc.gateway"
	echo "networkport.$ifc.gateway.value=$gateway"
	echo "networkport.$ifc.gateway.type=string"
	echo "networkport.$ifc.gateway.userConfigurable=true"
	echo "networkport.$ifc.gateway.label=Gateway IP for $ifc"
	echo "networkport.$ifc.gateway.description=Gateway IP Address for the network interface."

	let num=num+1
	netmask=$(ifconfig $ifc | sed -n 's/.*Mask:\(\S*\)/\1/p')
	echo "$class2.$num=networkport.$ifc.netmask"
	echo "networkport.$ifc.netmask.value=$netmask"
	echo "networkport.$ifc.netmask.type=string"
	echo "networkport.$ifc.netmask.userConfigurable=true"
	echo "networkport.$ifc.netmask.label=Netmask IP for $ifc"
	echo "networkport.$ifc.netmask.description=Network mask address for the network interface."
  
    shortname=`hostname`
    let num=num+1
	echo "$class2.$num=networkport.$ifc.hostname"
	echo "networkport.$ifc.hostname.value="
	echo "networkport.$ifc.hostname.type=string"
	echo "networkport.$ifc.hostname.userConfigurable=true"
	echo "networkport.$ifc.hostname.label=Short hostname for $ifc"
	echo "networkport.$ifc.hostname.description=Short hostname."

	let num=num+1
	echo "$class2.$num=networkport.$ifc.domainname"
	echo "networkport.$ifc.domainname.value=$domain"
	echo "networkport.$ifc.domainname.type=string"
	echo "networkport.$ifc.domainname.userConfigurable=true"
	echo "networkport.$ifc.domainname.label=Interface domain name for $ifc"
	echo "networkport.$ifc.domainname.description=Interface domain name."
  
  fi

done
